Appellate Division, Second Department, Decisions

Home > Decisions
Home Decisions Advanced Search Style Manual Research Citation Services

Archives

November, 2014
Cases Decided November 12, 2014
Title | Judge | Docket No. | Slip Opinion No.
| Barrocales v New York Methodist Hosp. |  | 2012-10641 | 2014 NY Slip Op 07606
Berrios-Lemus v Village of Spring Val. |  | 2014-03834 | 2014 NY Slip Op 07607
Bibeau v Sudick |  | 2013-01769 | 2014 NY Slip Op 07608
Blum v Accurate Chem. & Scientific Corp. |  | 2013-02295 | 2014 NY Slip Op 07609
Bregman v East Ramapo Cent. Sch. Dist. |  | 2013-05434 | 2014 NY Slip Op 07610
Bressler v Bressler |  | 2013-04621 | 2014 NY Slip Op 07611
Buchholz v A.L.A.C. Contr. Corp. |  | 2014-00277 | 2014 NY Slip Op 07612
Carroll-Batista v Bennett |  | 2013-10370 | 2014 NY Slip Op 07613
Clarke v First Student, Inc. |  | 2014-02808 | 2014 NY Slip Op 07614
Delanoy v City of White Plains |  | 2012-07860 | 2014 NY Slip Op 07615
Dish Realty, LLC v Town of Huntington |  | 2013-00220 | 2014 NY Slip Op 07616
Duvidovich v George |  | 2012-07448 | 2014 NY Slip Op 07617
Feldman v Merrick Union Free Sch. Dist. |  | 2013-01113 | 2014 NY Slip Op 07618
Felicciardi v Lankap Cab Corp. |  | 2014-04538 | 2014 NY Slip Op 07619
Fenner v 1011 Rte. 109 Corp. |  | 2014-00407 | 2014 NY Slip Op 07620
Flores v Luna |  | 2013-09807 | 2014 NY Slip Op 07621
Flores v Metropolitan Transp. Auth. |  | 2013-03497 | 2014 NY Slip Op 07622
Flowers v Bhola |  | 2014-02927 | 2014 NY Slip Op 07623
Frankenmuth Mut. Ins. Co. v Waste Mgt. of N.Y., LLC |  | 2012-08307 | 2014 NY Slip Op 07624
Frank-Shaevich v Anand |  | 2012-10306 | 2014 NY Slip Op 07625
Galette v Byrne |  | 2013-02554 | 2014 NY Slip Op 07626
Halberstam v Halberstam |  | 2013-10281 | 2014 NY Slip Op 07627
Henriquez v Rovt |  | 2013-06264 | 2014 NY Slip Op 07628
Hymowitz v City of New York |  | 2013-10215 | 2014 NY Slip Op 07629
Jordan v Metropolitan Jewish Hospice |  | 2012-10266 | 2014 NY Slip Op 07630
Knight v M & M Sanitation Corp. |  | 2012-06054 | 2014 NY Slip Op 07631
Leon Petroleum, LLC v Carl S. Levine & Assoc., P.C. |  | 2013-01116 | 2014 NY Slip Op 07632
Long Is. Pine Barrens Socy., Inc. v County of Suffolk |  | 2012-08838 | 2014 NY Slip Op 07633
McCourt v Wasilewski |  | 2013-06520 | 2014 NY Slip Op 07634
McGee v New York City Hous. Auth. |  | 2013-09148 | 2014 NY Slip Op 07635
Ogle v Higgins |  | 2013-10282 | 2014 NY Slip Op 07636
Palmeri v Erricola |  | 2014-01126 | 2014 NY Slip Op 07637
People v Dallas |  | 2012-11308 | 2014 NY Slip Op 07638
Pichardo v Zayas |  | 2013-10727 | 2014 NY Slip Op 07639
Pinilla v New York City Tr. Auth. |  | 2013-09759 | 2014 NY Slip Op 07640
Rajpurohit v Rajpurohit |  | 2013-07614 | 2014 NY Slip Op 07641
Ryan v Taconic Realty Assoc. |  | 2013-02785 | 2014 NY Slip Op 07642
Samet v Binson |  | 2013-08846 | 2014 NY Slip Op 07643
Schimko v Haley |  | 2013-03611 | 2014 NY Slip Op 07644
Silan v Sylvester |  | 2014-00924 | 2014 NY Slip Op 07645
Siskin v Cassar |  | 2012-07684 | 2014 NY Slip Op 07646
Smithie v Smithie |  | 2013-04610 | 2014 NY Slip Op 07647
Stewart v Citimortgage, Inc. |  | 2013-04976 | 2014 NY Slip Op 07648
Trunzo v Yannotti |  | 2013-10648 | 2014 NY Slip Op 07649
Vazquez v Gun Hill Assoc., LLC |  | 2013-09879 | 2014 NY Slip Op 07650
Velasco v 34-06 73rd St., LLC |  | 2013-05922 | 2014 NY Slip Op 07651
Wachovsky v City of New York |  | 2013-06882 | 2014 NY Slip Op 07652
Wells Fargo Bank, N.A. v Ali |  | 2013-00866 | 2014 NY Slip Op 07653
Wilcoxen v Palladino |  | 2013-10971 | 2014 NY Slip Op 07654
Wolf v Flowers |  | 2014-05534 | 2014 NY Slip Op 07655
Young Sun Chung v Kwah |  | 2013-09452 | 2014 NY Slip Op 07656
Matter of Isser B. (Abraham A.B.) |  | 2013-00732 | 2014 NY Slip Op 07657
Matter of Bonaguro v City of New York |  | 2014-00783 | 2014 NY Slip Op 07658
Matter of Edemodu v Scott |  | 2013-09703 | 2014 NY Slip Op 07659
Matter of Flournoy v Supreme Ct. Clerk |  | 2013-00708 | 2014 NY Slip Op 07660
Matter of Courtland H. |  | 2013-09577 | 2014 NY Slip Op 07661
Matter of HP Ronkonkoma, Inc. v Kirkland |  | 2012-10726 | 2014 NY Slip Op 07662
Matter of JP & Assoc. Corp. v New York State Div. of Hous. & Community Renewal |  | 2012-04939 | 2014 NY Slip Op 07663
Matter of JP & Assoc. Corp. v New York State Div. of Hous. & Community Renewal |  | 2013-05951 | 2014 NY Slip Op 07664
Matter of McLennan v Gordon |  | 2013-08621 | 2014 NY Slip Op 07665
Matter of O'Gorman v O'Gorman |  | 2013-10666 | 2014 NY Slip Op 07666
Matter of O'Gorman v O'Gorman |  | 2014-03630 | 2014 NY Slip Op 07667
Matter of Progressive Specialty Ins. Co. v Alexis |  | 2013-03364 | 2014 NY Slip Op 07668
Matter of Reina R. (Erica R.) |  | 2013-10401 | 2014 NY Slip Op 07669
Matter of Dayshawn S. |  | 2013-01760 | 2014 NY Slip Op 07670
Matter of Kobe S. |  | 2013-09648 | 2014 NY Slip Op 07671
Matter of Ya-Sin S. |  | 2013-08486 | 2014 NY Slip Op 07672
Matter of SLS Residential, Inc. v New York State Off. of Mental Health |  | 2013-02723 | 2014 NY Slip Op 07673
Matter of Sutherland v New York State Dept. of Envtl. Conservation |  | 2012-06337 | 2014 NY Slip Op 07674
Matter of Yu F. (Fen W.) |  | 2013-06477 | 2014 NY Slip Op 07675
People v Almonor |  | 2010-06811 | 2014 NY Slip Op 07676
People v Alvarezjolon |  | 2013-11254 | 2014 NY Slip Op 07677
People v Bell |  | 2012-11174 | 2014 NY Slip Op 07678
People v Caliste |  | 2014-00934 | 2014 NY Slip Op 07679
People v Clarke |  | 2011-00253 | 2014 NY Slip Op 07680
People v Grant |  | 2012-05994 | 2014 NY Slip Op 07681
People v Gueye |  | 2006-11193 | 2014 NY Slip Op 07682
People v Haywood |  | 2013-09036 | 2014 NY Slip Op 07683
People v Holmes |  | 2012-08897 | 2014 NY Slip Op 07684
People v Lazier |  | 2012-08628 | 2014 NY Slip Op 07685
People v Leach |  | 2012-09143 | 2014 NY Slip Op 07686
People v Licausi |  | 2010-11430 | 2014 NY Slip Op 07687
People v Pendelton |  | 2013-10157 | 2014 NY Slip Op 07688
People v Perry |  | 2012-03741 | 2014 NY Slip Op 07689
People v Poliandro |  | 2013-01375 | 2014 NY Slip Op 07690
People v Rodas |  | 2013-02821 | 2014 NY Slip Op 07691
People v Sanchez |  | 2012-07077 | 2014 NY Slip Op 07692
People v Sassi |  | 2014-00324 | 2014 NY Slip Op 07693
People v Williams |  | 2013-04256 | 2014 NY Slip Op 07694

Cases Decided November 5, 2014
Title | Judge | Docket No. | Slip Opinion No.
Abato v Beller |  | 2011-07816 | 2014 NY Slip Op 07460
Altreche v City of New York |  | 2013-04503 | 2014 NY Slip Op 07461
Aurora Loan Servs., LLC v Ahmed |  | 2012-09805 | 2014 NY Slip Op 07462
Balashanskaya v Polymed Community Care Ctr., P.C. |  | 2013-08192 | 2014 NY Slip Op 07463
Bellissimo v Mitchell |  | 2012-10123 | 2014 NY Slip Op 07464
Browne v Board of Educ. |  | 2013-07351 | 2014 NY Slip Op 07465
Bryant v Broadcast Music, Inc. |  | 2012-06642 | 2014 NY Slip Op 07466
Dcfs Usa, LLC v Metro Constr. Equities |  | 2012-08518 | 2014 NY Slip Op 07467
Deutsche Bank Natl. Trust Co. v Islar |  | 2013-06996 | 2014 NY Slip Op 07468
DiMauro v United, LLC |  | 2013-02221 | 2014 NY Slip Op 07469
Green Apple Mgt. Corp. v Aronis |  | 2013-00519 | 2014 NY Slip Op 07470
Hairman v Jhawarer |  | 2012-11516 | 2014 NY Slip Op 07471
Hampshire Props. v BTA Bldg. & Developing, Inc. |  | 2013-09277 | 2014 NY Slip Op 07472
Hinz v Hinz |  | 2013-06086 | 2014 NY Slip Op 07473
Holand v Cascino |  | 2014-03389 | 2014 NY Slip Op 07474
JP Morgan Chase Bank, N.A. v Hall |  | 2012-08439 | 2014 NY Slip Op 07475
Kane v Galtieri |  | 2012-11130 | 2014 NY Slip Op 07476
Leach v Ocean Black Car Corp. |  | 2013-05352 | 2014 NY Slip Op 07477
Master v Boiakhtchion |  | 2013-08412 | 2014 NY Slip Op 07478
Miller v City of New York |  | 2013-05480 | 2014 NY Slip Op 07479
Han v BJ Laura & Son, Inc. |  | 2013-06273 | 2014 NY Slip Op 07480
Mizuno v Nunberg |  | 2013-06709 | 2014 NY Slip Op 07481
MRI Enters., Inc. v Comprehensive Med. Care of N.Y., P.C. |  | 2012-11023 | 2014 NY Slip Op 07482
Nour v City of New York |  | 2012-10986 | 2014 NY Slip Op 07483
Ortiz v All Lock & Glass Serv., Inc. |  | 2013-02146 | 2014 NY Slip Op 07484
People v Coleman |  | 2012-05592 | 2014 NY Slip Op 07485
People v Padin |  | 2013-10806 | 2014 NY Slip Op 07486
Prakhin v Fulton Towers Realty Corp. |  | 2013-04032 | 2014 NY Slip Op 07487
Rodriguez v 1790 Broadway Assoc., LLC |  | 2012-11158 | 2014 NY Slip Op 07488
Rosenblum v Great Neck Teachers Assn. Benefit Trust Fund |  | 2012-08805 | 2014 NY Slip Op 07489
Ross v Jamaica Hosp. Med. Ctr. |  | 2012-11599 | 2014 NY Slip Op 07490
Serrano v Lutheran Social Servs. of Metro. N.Y., Inc. |  | 2013-02975 | 2014 NY Slip Op 07491
Slonecki v Damm |  | 2012-08478 | 2014 NY Slip Op 07492
Stenberg v Kalansky |  | 2012-11571 | 2014 NY Slip Op 07493
Tucholski v State of New York |  | 2013-10623 | 2014 NY Slip Op 07494
U.S. Mdse., Inc. v L&R Distribs., Inc. |  | 2013-00497 | 2014 NY Slip Op 07495
Uribe v Uribe |  | 2013-02869 | 2014 NY Slip Op 07496
Vinasco v Intell Times Sq. Hotel, LLC |  | 2013-01467 | 2014 NY Slip Op 07497
Volodarsky v Moonlight Ambulette Serv., Inc. |  | 2012-07533 | 2014 NY Slip Op 07498
Wolfe v North Merrick Union Free School Dist. |  | 2013-09933 | 2014 NY Slip Op 07499
Matter of Jemel M. A. (Elizabeth C. B. A.) |  | 2013-08514 | 2014 NY Slip Op 07500
Matter of Belton v Spota |  | 2014-04430, | 2014 NY Slip Op 07501
Matter of Boodhoo v Rampersaud |  | 2013-09514 | 2014 NY Slip Op 07502
Matter of Burke v Cogan |  | 2014-01097 | 2014 NY Slip Op 07503
Matter of Cooper v Lathillerie |  | 2014-00142 | 2014 NY Slip Op 07504
Matter of Edwards v Incorporated Vil. of Hempstead |  | 2013-02344 | 2014 NY Slip Op 07505
Matter of Executive Life Ins. Co. of N.Y. (Dolan) |  | 2013-02335 | 2014 NY Slip Op 07506
Matter of Kaydance H. G. (Carmen M.) |  | 2013-09630 | 2014 NY Slip Op 07507
Matter of Goll |  | 2003-10710 | 2014 NY Slip Op 07508
Matter of Guiracocha v Amaro |  | 2013-10643 | 2014 NY Slip Op 07509
Matter of Harrison v Palumbo |  | 2012-10651 | 2014 NY Slip Op 07510
Matter of Lopez v New York State Div. of Human Rights |  | 2013-05350 | 2014 NY Slip Op 07511
Matter of Mondschein v Mondschein |  | 2013-11379 | 2014 NY Slip Op 07512
Matter of Progressive Specialty Ins. Co. v Louis |  | 2013-01455 | 2014 NY Slip Op 07513
Matter of State of New York v Leroy P. |  | 2012-10927 | 2014 NY Slip Op 07514
People v Armstead |  | 2012-07212 | 2014 NY Slip Op 07515
People v Banner |  | 2012-08899 | 2014 NY Slip Op 07516
People v Dorvilier |  | 2012-09701 | 2014 NY Slip Op 07517
People v Grant |  | 2008-10586 | 2014 NY Slip Op 07518
People v Heine |  | 2013-00015 | 2014 NY Slip Op 07519
People v Louis |  | 2012-03401 | 2014 NY Slip Op 07520
People v Sanchez |  | 2013-03965 | 2014 NY Slip Op 07521
People v Williams |  | 2012-07893 | 2014 NY Slip Op 07522

Home | Contents | Site Search | Publications | Decisions | Decision Search
Citation Services | Archives | Style Manual | Legal Research Portal
New York State Law Reporting Bureau
17 Lodge Street, Albany, NY 12207
phone: (518) 453-6900
fax: (518) 426-1640